==> cscec5b-wzxt-api-3.0.0-20210323.093200-181-sources.jar: com/ejianc/business/wzxt/vo/ExitDetailGFVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitDetailGFVO{
    private static final long serialVersionUID = 1L;

    private Long id;
    private Long exitId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private Long materialTypeId; // 物资类别
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String stopDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private java.math.BigDecimal applyNums; // 申请退场数量
    private java.math.BigDecimal exitNums; // 本次退场数量
    private java.math.BigDecimal exitNumsSum; // 累计退场数量

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getExitId() {
        return exitId;
    }

    public void setExitId(Long exitId) {
        this.exitId = exitId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getStopDate() {
        return stopDate;
    }

    public void setStopDate(String stopDate) {
        this.stopDate = stopDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
}

==> cscec5b-wzxt-api-3.0.0-20210706.083735-274-sources.jar: com/ejianc/business/wzxt/vo/ExitDetailGFVO.java <==
package com.ejianc.business.wzxt.vo;

import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 推送供方明细
 * 
 * @author syj
 * 
 */
public class ExitDetailGFVO{
    private static final long serialVersionUID = 1L;

    private String id;
    private String exitId; // 退场主键ID
    private String materialId; // 物资主键
    private String materialName; // 物资名称
    private String materialTypeName; // 物资类别名称
    private String materialCode; // 物料编码
    private String unit; // 单位
    private String spec; // 规格型号
    private String memo; // 备注
    private String stopDate; // 止租日
    private String def1; //
    private String def2; //
    private String def3; //
    private String def4; //
    private String def5; //
    private java.math.BigDecimal applyNums; // 申请退场数量
    private java.math.BigDecimal exitNums; // 本次退场数量
    private java.math.BigDecimal exitNumsSum; // 累计退场数量

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getExitId() {
        return exitId;
    }

    public void setExitId(String exitId) {
        this.exitId = exitId;
    }

    public String getMaterialId() {
        return materialId;
    }

    public void setMaterialId(String materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getStopDate() {
        return stopDate;
    }

    public void setStopDate(String stopDate) {
        this.stopDate = stopDate;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public BigDecimal getApplyNums() {
        return applyNums;
    }

    public void setApplyNums(BigDecimal applyNums) {
        this.applyNums = applyNums;
    }

    public BigDecimal getExitNums() {
        return exitNums;
    }

    public void setExitNums(BigDecimal exitNums) {
        this.exitNums = exitNums;
    }

    public BigDecimal getExitNumsSum() {
        return exitNumsSum;
    }

    public void setExitNumsSum(BigDecimal exitNumsSum) {
        this.exitNumsSum = exitNumsSum;
    }
}
